@@ -77,9 +77,12 @@ ret_t cherokee_post_init           (cherokee_post_t *post);
 ret_t cherokee_post_clean          (cherokee_post_t *post);
 ret_t cherokee_post_mrproper       (cherokee_post_t *post);
 
-ret_t cherokee_post_read_header    (cherokee_post_t *post, void *conn);
-ret_t cherokee_post_has_info       (cherokee_post_t *post);
-int   cherokee_post_read_finished  (cherokee_post_t *post);
+ret_t cherokee_post_read_header       (cherokee_post_t   *post, void *conn);
+ret_t cherokee_post_has_info          (cherokee_post_t   *post);
+int   cherokee_post_read_finished     (cherokee_post_t   *post);
+int   cherokee_post_has_buffered_info (cherokee_post_t   *post,
+				       cherokee_buffer_t *tmp);
+
 
 /* Read
  */
